@@ -27,8 +27,8 @@
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-utils.h>
 
-#include "tracker-main.h"
-#include "tracker-xmp.h"
+#include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-xmp.h>
 
 static void extract_xmp (const gchar          *filename,
                          TrackerSparqlBuilder *metadata);
@@ -150,12 +150,12 @@ extract_xmp (const gchar          *uri,
 		/* If no orig file is found for the sidekick, we use the sidekick to
 		 * describe itself instead, falling back to uri */
 
-		tracker_read_xmp (contents,
+		tracker_xmp_read (contents,
 		                  length,
 		                  orig_uri ? orig_uri : uri,
 		                  &xmp_data);
 
-		tracker_apply_xmp (metadata, uri, &xmp_data);
+		tracker_xmp_apply (metadata, uri, &xmp_data);
 
 		g_free (orig_uri);
 	}
@@ -165,7 +165,7 @@ extract_xmp (const gchar          *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
