@@ -488,19 +488,18 @@ get_music_albums_foreach (gpointer value,
 
 	g_print ("  "); /*'%s', ", data[1]);*/
 	g_print (g_dngettext (NULL,
-	                      "%d Song",
-	                      "%d Songs",
+	                      "%d song",
+	                      "%d songs",
 	                      atoi (data[2])),
 	         atoi (data[2]));
 
 	g_print (", ");
 	g_print (g_dngettext (NULL,
-	                      "%d Second",
-	                      "%d Seconds",
+	                      "%d second",
+	                      "%d seconds",
 	                      atoi (data[3])),
 	         atoi (data[3]));
-	g_print (", ");
-	g_print (_("Album '%s'"), data[1]);
+	g_print (", '%s'", data[1]);
 	g_print ("\n");
 }
 
@@ -519,14 +518,12 @@ get_music_albums (TrackerClient *client,
 	fts = get_fts_string (search_words, use_or_operator);
 
 	if (fts) {
-		query = g_strdup_printf ("SELECT ?album ?title COUNT(?song) "
+		query = g_strdup_printf ("SELECT ?album nie:title (?album) COUNT(?song) "
 		                         "AS songs "
-		                         "SUM(?length) AS totallength "
+		                         "SUM(nmm:length (?length)) AS totallength "
 		                         "WHERE {"
-		                         "  ?album a nmm:MusicAlbum ;"
-		                         "  nie:title ?title ."
-		                         "  ?song nmm:musicAlbum ?album ;"
-		                         "  nmm:length ?length ."
+		                         "  ?album a nmm:MusicAlbum ."
+		                         "  ?song nmm:musicAlbum ?album ."
 		                         "  ?album fts:match \"%s\" "
 		                         "} "
 		                         "GROUP BY ?album "
@@ -536,14 +533,12 @@ get_music_albums (TrackerClient *client,
 		                         search_offset,
 		                         search_limit);
 	} else {
-		query = g_strdup_printf ("SELECT ?album ?title COUNT(?song) "
+		query = g_strdup_printf ("SELECT ?album nie:title (?album) COUNT(?song) "
 		                         "AS songs "
-		                         "SUM(?length) AS totallength "
+		                         "SUM(nmm:length (?length)) AS totallength "
 		                         "WHERE {"
-		                         "  ?album a nmm:MusicAlbum ;"
-		                         "  nie:title ?title ."
-		                         "  ?song nmm:musicAlbum ?album ;"
-		                         "  nmm:length ?length ."
+		                         "  ?album a nmm:MusicAlbum ."
+		                         "  ?song nmm:musicAlbum ?album ." 
 		                         "} "
 		                         "GROUP BY ?album "
 		                         "OFFSET %d "
@@ -834,9 +829,54 @@ main (int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
+	g_type_init ();
+
+	if (!g_thread_supported ()) {
+		g_thread_init (NULL);
+	}
+
+	/* Check terms are not stopwords */
+	if (terms) {
+		TrackerLanguage *language;
+		GHashTable *stop_words;
+		const gchar *stop_word_found;
+		gchar **p;
+
+		language = tracker_language_new (NULL);
+		stop_words = tracker_language_get_stop_words (language);
+
+		for (p = terms, stop_word_found = NULL; *p && !stop_word_found; p++) {
+			gpointer data;
+
+			data = g_hash_table_lookup (stop_words, *p);
+			if (data) {
+				stop_word_found = *p;
+			}
+		}
+
+		if (stop_word_found) {
+			g_printerr (_("Search term '%s' is a stop word."),
+			            stop_word_found);
+			g_printerr ("\n\n");
+			g_printerr (_("Stop words are common words which are "
+			              "ignored during the indexing process."));
+			g_printerr ("\n");
+			g_printerr (_("This means this search term will never "
+			              "be found when matching FTS entries."));
+			g_printerr ("\n\n");
+
+			g_option_context_free (context);
+			g_object_unref (language);
+
+			return EXIT_FAILURE;
+		}
+
+		g_object_unref (language);
+	}
+
 	g_option_context_free (context);
 
-	client = tracker_connect (FALSE, G_MAXINT);
+	client = tracker_client_new (0, G_MAXINT);
 
 	if (!client) {
 		g_printerr ("%s\n",
@@ -852,7 +892,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_files (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -861,7 +901,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_folders (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -870,7 +910,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_music_albums (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -879,7 +919,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_music_artists (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -888,7 +928,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_music_files (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -897,7 +937,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_image_files (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -906,7 +946,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_video_files (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -915,7 +955,7 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_document_files (client, terms, offset, limit, or_operator);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
@@ -924,12 +964,12 @@ main (int argc, char **argv)
 		gboolean success;
 
 		success = get_all_by_search (client, terms, offset, limit, or_operator, detailed);
-		tracker_disconnect (client);
+		g_object_unref (client);
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
 
-	tracker_disconnect (client);
+	g_object_unref (client);
 
 	return EXIT_SUCCESS;
 }
